.. _modules_index:

MetaWear modules
================

.. toctree::
   :maxdepth: 1

   base
   accelerometer
   gyroscope
   magnetometer
   barometer
   led
   settings
   haptic
   switch
   temperature
